@@ -6,6 +6,6 @@ SETTINGS = EmmetBuildSettings()
 
 try:
     __version__ = get_distribution("emmet-builders").version
-except DistributionNotFound:
+except DistributionNotFound:  # pragma: no cover
     # package is not installed
     pass
